@@ -2,12 +2,15 @@ import pickle
 import random
 import pytest
 import sympy
+import numpy
 
 from fractions import Fraction as Q
 
 from pyadic import ModP, PAdic
-from pyadic.finite_field import extended_euclideal_algorithm, rationalise, MQRR, LGRR, finite_field_sqrt, chained_chinese_remainder
+from pyadic.finite_field import vec_ModP, extended_euclideal_algorithm, rationalise, MQRR, LGRR, \
+    finite_field_sqrt, chained_chinese_remainder, vec_chained_FF_rationalize
 from pyadic.field_extension import FieldExtension
+from pyadic.primes import primes
 
 
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ #
@@ -82,6 +85,13 @@ def test_multiplication():
     assert (a * b) % p == ModP(a, p) * b
 
 
+def test_multiplication_with_array():
+    p = 10007
+    a = random.randrange(0, 10000)
+    array = [0, 1, 2, 3]
+    assert numpy.all(ModP(a, p) * numpy.array(array) == numpy.array([ModP(a, p) * entry for entry in array]))
+
+
 def test_division():
     p = 10007
     a, b = random.randrange(1, p - 1), random.randrange(1, p - 1)
@@ -145,7 +155,7 @@ def test_extended_euclideal_algorithm():
     for i in range(10):
         a, b = random.randint(1, 1000), random.randint(1, 1000)
         s, t, gcd = extended_euclideal_algorithm(a, b)
-        assert(a * s + b * t == gcd)
+        assert a * s + b * t == gcd
 
 
 def test_reconstruction_MQRR_2147483647():
@@ -175,3 +185,10 @@ def test_sqrt_in_field_extension():
 
 def test_sqrt_in_fintie_field():
     assert not isinstance(finite_field_sqrt(ModP(-1, 2 ** 31 - 19)), FieldExtension)
+
+
+def test_vec_chained_FF_rationalize():
+    Qmatrix = numpy.array([[Q(16, 9973), Q(10007)], [Q(99991, 4), Q(100003)]])
+    used_primes = primes[:4]
+    FF_matrices = [vec_ModP(prime)(Qmatrix).astype(int) for prime in used_primes]
+    assert numpy.all(vec_chained_FF_rationalize(FF_matrices, used_primes) == Qmatrix)
